@@ -19,7 +19,7 @@ def fetch(url):
         return s.fetch(url)
 
 
-def load_session(fn=None):
+def load_state(fn=None):
     """
     loads as session state saved in file <fn>
     Args:
